pitchtools.is_chromatic_pitch_class_name_octave_number_pair
===========================================================

.. autofunction:: abjad.tools.pitchtools.is_chromatic_pitch_class_name_octave_number_pair.is_chromatic_pitch_class_name_octave_number_pair
